import pycurl

class Handle:
    def __init__(self, handle: pycurl.Curl) -> None: ...
    def setopt(self, option: int, value: object, /) -> None: ...
    def unsetopt(self, option: int, /) -> None: ...
    def getinfo(self, option: int, /) -> object: ...
    def getinfo_raw(self, option: int, /) -> object: ...
    def pause(self, state: int, /) -> None: ...
