class CurlError(Exception):
    args: tuple[int, str]
    def __init__(self, code: int, msg: str) -> None: ...
    @property
    def code(self) -> int: ...
    @property
    def msg(self) -> str: ...
