from .abc import ConfigHandle as ConfigHandle, GetInfoHandle as GetInfoHandle
from typing import IO

class Request:
    url: str
    destination: IO[bytes]
    def __init__(self, url: str, destination: IO[bytes]) -> None: ...
    def configure_handle(self, handle: ConfigHandle, /) -> None: ...
    def has_update(self, /) -> bool: ...
    def get_update(self, /) -> None: ...
    def completed(self, handle: GetInfoHandle, /) -> None: ...
